/*******************************************************************************
* File Name: PWMxIn.c  
* Version 2.0
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "PWMxIn.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 PWMxIn__PORT == 15 && ((PWMxIn__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: PWMxIn_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void PWMxIn_Write(uint8 value) 
{
    uint8 staticBits = (PWMxIn_DR & (uint8)(~PWMxIn_MASK));
    PWMxIn_DR = staticBits | ((uint8)(value << PWMxIn_SHIFT) & PWMxIn_MASK);
}


/*******************************************************************************
* Function Name: PWMxIn_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  PWMxIn_DM_STRONG     Strong Drive 
*  PWMxIn_DM_OD_HI      Open Drain, Drives High 
*  PWMxIn_DM_OD_LO      Open Drain, Drives Low 
*  PWMxIn_DM_RES_UP     Resistive Pull Up 
*  PWMxIn_DM_RES_DWN    Resistive Pull Down 
*  PWMxIn_DM_RES_UPDWN  Resistive Pull Up/Down 
*  PWMxIn_DM_DIG_HIZ    High Impedance Digital 
*  PWMxIn_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void PWMxIn_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(PWMxIn_0, mode);
}


/*******************************************************************************
* Function Name: PWMxIn_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro PWMxIn_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 PWMxIn_Read(void) 
{
    return (PWMxIn_PS & PWMxIn_MASK) >> PWMxIn_SHIFT;
}


/*******************************************************************************
* Function Name: PWMxIn_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 PWMxIn_ReadDataReg(void) 
{
    return (PWMxIn_DR & PWMxIn_MASK) >> PWMxIn_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(PWMxIn_INTSTAT) 

    /*******************************************************************************
    * Function Name: PWMxIn_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 PWMxIn_ClearInterrupt(void) 
    {
        return (PWMxIn_INTSTAT & PWMxIn_MASK) >> PWMxIn_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
