/*******************************************************************************
* File Name: PeriodISR.c  
* Version 1.70
*
*  Description:
*   API for controlling the state of an interrupt.
*
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/


#include <cydevice_trm.h>
#include <CyLib.h>
#include <PeriodISR.h>

#if !defined(PeriodISR__REMOVED) /* Check for removal by optimization */

/*******************************************************************************
*  Place your includes, defines and code here 
********************************************************************************/
/* `#START PeriodISR_intc` */

#include <project.h>

extern volatile uint16 PWMxInPeriod;

/* `#END` */

#ifndef CYINT_IRQ_BASE
#define CYINT_IRQ_BASE      16
#endif /* CYINT_IRQ_BASE */
#ifndef CYINT_VECT_TABLE
#define CYINT_VECT_TABLE    ((cyisraddress **) CYREG_NVIC_VECT_OFFSET)
#endif /* CYINT_VECT_TABLE */

/* Declared in startup, used to set unused interrupts to. */
CY_ISR_PROTO(IntDefaultHandler);


/*******************************************************************************
* Function Name: PeriodISR_Start
********************************************************************************
*
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   None
*
* Return:
*   None
*
*******************************************************************************/
void PeriodISR_Start(void)
{
    /* For all we know the interrupt is active. */
    PeriodISR_Disable();

    /* Set the ISR to point to the PeriodISR Interrupt. */
    PeriodISR_SetVector(&PeriodISR_Interrupt);

    /* Set the priority. */
    PeriodISR_SetPriority((uint8)PeriodISR_INTC_PRIOR_NUMBER);

    /* Enable it. */
    PeriodISR_Enable();
}


/*******************************************************************************
* Function Name: PeriodISR_StartEx
********************************************************************************
*
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   address: Address of the ISR to set in the interrupt vector table.
*
* Return:
*   None
*
*******************************************************************************/
void PeriodISR_StartEx(cyisraddress address)
{
    /* For all we know the interrupt is active. */
    PeriodISR_Disable();

    /* Set the ISR to point to the PeriodISR Interrupt. */
    PeriodISR_SetVector(address);

    /* Set the priority. */
    PeriodISR_SetPriority((uint8)PeriodISR_INTC_PRIOR_NUMBER);

    /* Enable it. */
    PeriodISR_Enable();
}


/*******************************************************************************
* Function Name: PeriodISR_Stop
********************************************************************************
*
* Summary:
*   Disables and removes the interrupt.
*
* Parameters:  
*
* Return:
*   None
*
*******************************************************************************/
void PeriodISR_Stop(void)
{
    /* Disable this interrupt. */
    PeriodISR_Disable();

    /* Set the ISR to point to the passive one. */
    PeriodISR_SetVector(&IntDefaultHandler);
}


/*******************************************************************************
* Function Name: PeriodISR_Interrupt
********************************************************************************
*
* Summary:
*   The default Interrupt Service Routine for PeriodISR.
*
*   Add custom code between the coments to keep the next version of this file
*   from over writting your code.
*
* Parameters:  
*
* Return:
*   None
*
*******************************************************************************/
CY_ISR(PeriodISR_Interrupt)
{
    /*  Place your Interrupt code here. */
    /* `#START PeriodISR_Interrupt` */
    
    Counter_Stop();
    PWMxInPeriod = Counter_ReadCounter();
    PulsehitimeISR_Disable( );
    Counter_WritePeriod(0);
    Counter_Start();
    PulsehitimeISR_Enable();
    return;


    /* `#END` */
}


/*******************************************************************************
* Function Name: PeriodISR_SetVector
********************************************************************************
*
* Summary:
*   Change the ISR vector for the Interrupt. Note calling PeriodISR_Start
*   will override any effect this method would have had. To set the vector 
*   before the component has been started use PeriodISR_StartEx instead.
*
* Parameters:
*   address: Address of the ISR to set in the interrupt vector table.
*
* Return:
*   None
*
*******************************************************************************/
void PeriodISR_SetVector(cyisraddress address)
{
    cyisraddress * ramVectorTable;

    ramVectorTable = (cyisraddress *) *CYINT_VECT_TABLE;

    ramVectorTable[CYINT_IRQ_BASE + (uint32)PeriodISR__INTC_NUMBER] = address;
}


/*******************************************************************************
* Function Name: PeriodISR_GetVector
********************************************************************************
*
* Summary:
*   Gets the "address" of the current ISR vector for the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   Address of the ISR in the interrupt vector table.
*
*******************************************************************************/
cyisraddress PeriodISR_GetVector(void)
{
    cyisraddress * ramVectorTable;

    ramVectorTable = (cyisraddress *) *CYINT_VECT_TABLE;

    return ramVectorTable[CYINT_IRQ_BASE + (uint32)PeriodISR__INTC_NUMBER];
}


/*******************************************************************************
* Function Name: PeriodISR_SetPriority
********************************************************************************
*
* Summary:
*   Sets the Priority of the Interrupt. Note calling PeriodISR_Start
*   or PeriodISR_StartEx will override any effect this method 
*   would have had. This method should only be called after 
*   PeriodISR_Start or PeriodISR_StartEx has been called. To set 
*   the initial priority for the component use the cydwr file in the tool.
*
* Parameters:
*   priority: Priority of the interrupt. 0 - 7, 0 being the highest.
*
* Return:
*   None
*
*******************************************************************************/
void PeriodISR_SetPriority(uint8 priority)
{
    *PeriodISR_INTC_PRIOR = priority << 5;
}


/*******************************************************************************
* Function Name: PeriodISR_GetPriority
********************************************************************************
*
* Summary:
*   Gets the Priority of the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   Priority of the interrupt. 0 - 7, 0 being the highest.
*
*******************************************************************************/
uint8 PeriodISR_GetPriority(void)
{
    uint8 priority;


    priority = *PeriodISR_INTC_PRIOR >> 5;

    return priority;
}


/*******************************************************************************
* Function Name: PeriodISR_Enable
********************************************************************************
*
* Summary:
*   Enables the interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void PeriodISR_Enable(void)
{
    /* Enable the general interrupt. */
    *PeriodISR_INTC_SET_EN = PeriodISR__INTC_MASK;
}


/*******************************************************************************
* Function Name: PeriodISR_GetState
********************************************************************************
*
* Summary:
*   Gets the state (enabled, disabled) of the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   1 if enabled, 0 if disabled.
*
*******************************************************************************/
uint8 PeriodISR_GetState(void)
{
    /* Get the state of the general interrupt. */
    return ((*PeriodISR_INTC_SET_EN & (uint32)PeriodISR__INTC_MASK) != 0u) ? 1u:0u;
}


/*******************************************************************************
* Function Name: PeriodISR_Disable
********************************************************************************
*
* Summary:
*   Disables the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void PeriodISR_Disable(void)
{
    /* Disable the general interrupt. */
    *PeriodISR_INTC_CLR_EN = PeriodISR__INTC_MASK;
}


/*******************************************************************************
* Function Name: PeriodISR_SetPending
********************************************************************************
*
* Summary:
*   Causes the Interrupt to enter the pending state, a software method of
*   generating the interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void PeriodISR_SetPending(void)
{
    *PeriodISR_INTC_SET_PD = PeriodISR__INTC_MASK;
}


/*******************************************************************************
* Function Name: PeriodISR_ClearPending
********************************************************************************
*
* Summary:
*   Clears a pending interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void PeriodISR_ClearPending(void)
{
    *PeriodISR_INTC_CLR_PD = PeriodISR__INTC_MASK;
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
