/*******************************************************************************
* File Name: PulsehitimeISR.c  
* Version 1.70
*
*  Description:
*   API for controlling the state of an interrupt.
*
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/


#include <cydevice_trm.h>
#include <CyLib.h>
#include <PulsehitimeISR.h>

#if !defined(PulsehitimeISR__REMOVED) /* Check for removal by optimization */

/*******************************************************************************
*  Place your includes, defines and code here 
********************************************************************************/
/* `#START PulsehitimeISR_intc` */
	
#include <project.h>

extern volatile uint16 PulseHighTime;
	
/* `#END` */

#ifndef CYINT_IRQ_BASE
#define CYINT_IRQ_BASE      16
#endif /* CYINT_IRQ_BASE */
#ifndef CYINT_VECT_TABLE
#define CYINT_VECT_TABLE    ((cyisraddress **) CYREG_NVIC_VECT_OFFSET)
#endif /* CYINT_VECT_TABLE */

/* Declared in startup, used to set unused interrupts to. */
CY_ISR_PROTO(IntDefaultHandler);


/*******************************************************************************
* Function Name: PulsehitimeISR_Start
********************************************************************************
*
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   None
*
* Return:
*   None
*
*******************************************************************************/
void PulsehitimeISR_Start(void)
{
    /* For all we know the interrupt is active. */
    PulsehitimeISR_Disable();

    /* Set the ISR to point to the PulsehitimeISR Interrupt. */
    PulsehitimeISR_SetVector(&PulsehitimeISR_Interrupt);

    /* Set the priority. */
    PulsehitimeISR_SetPriority((uint8)PulsehitimeISR_INTC_PRIOR_NUMBER);

    /* Enable it. */
    PulsehitimeISR_Enable();
}


/*******************************************************************************
* Function Name: PulsehitimeISR_StartEx
********************************************************************************
*
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   address: Address of the ISR to set in the interrupt vector table.
*
* Return:
*   None
*
*******************************************************************************/
void PulsehitimeISR_StartEx(cyisraddress address)
{
    /* For all we know the interrupt is active. */
    PulsehitimeISR_Disable();

    /* Set the ISR to point to the PulsehitimeISR Interrupt. */
    PulsehitimeISR_SetVector(address);

    /* Set the priority. */
    PulsehitimeISR_SetPriority((uint8)PulsehitimeISR_INTC_PRIOR_NUMBER);

    /* Enable it. */
    PulsehitimeISR_Enable();
}


/*******************************************************************************
* Function Name: PulsehitimeISR_Stop
********************************************************************************
*
* Summary:
*   Disables and removes the interrupt.
*
* Parameters:  
*
* Return:
*   None
*
*******************************************************************************/
void PulsehitimeISR_Stop(void)
{
    /* Disable this interrupt. */
    PulsehitimeISR_Disable();

    /* Set the ISR to point to the passive one. */
    PulsehitimeISR_SetVector(&IntDefaultHandler);
}


/*******************************************************************************
* Function Name: PulsehitimeISR_Interrupt
********************************************************************************
*
* Summary:
*   The default Interrupt Service Routine for PulsehitimeISR.
*
*   Add custom code between the coments to keep the next version of this file
*   from over writting your code.
*
* Parameters:  
*
* Return:
*   None
*
*******************************************************************************/
CY_ISR(PulsehitimeISR_Interrupt)
{
    /*  Place your Interrupt code here. */
    /* `#START PulsehitimeISR_Interrupt` */
	
    PulseHighTime=Counter_ReadCapture();
    return;
	
    /* `#END` */
}


/*******************************************************************************
* Function Name: PulsehitimeISR_SetVector
********************************************************************************
*
* Summary:
*   Change the ISR vector for the Interrupt. Note calling PulsehitimeISR_Start
*   will override any effect this method would have had. To set the vector 
*   before the component has been started use PulsehitimeISR_StartEx instead.
*
* Parameters:
*   address: Address of the ISR to set in the interrupt vector table.
*
* Return:
*   None
*
*******************************************************************************/
void PulsehitimeISR_SetVector(cyisraddress address)
{
    cyisraddress * ramVectorTable;

    ramVectorTable = (cyisraddress *) *CYINT_VECT_TABLE;

    ramVectorTable[CYINT_IRQ_BASE + (uint32)PulsehitimeISR__INTC_NUMBER] = address;
}


/*******************************************************************************
* Function Name: PulsehitimeISR_GetVector
********************************************************************************
*
* Summary:
*   Gets the "address" of the current ISR vector for the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   Address of the ISR in the interrupt vector table.
*
*******************************************************************************/
cyisraddress PulsehitimeISR_GetVector(void)
{
    cyisraddress * ramVectorTable;

    ramVectorTable = (cyisraddress *) *CYINT_VECT_TABLE;

    return ramVectorTable[CYINT_IRQ_BASE + (uint32)PulsehitimeISR__INTC_NUMBER];
}


/*******************************************************************************
* Function Name: PulsehitimeISR_SetPriority
********************************************************************************
*
* Summary:
*   Sets the Priority of the Interrupt. Note calling PulsehitimeISR_Start
*   or PulsehitimeISR_StartEx will override any effect this method 
*   would have had. This method should only be called after 
*   PulsehitimeISR_Start or PulsehitimeISR_StartEx has been called. To set 
*   the initial priority for the component use the cydwr file in the tool.
*
* Parameters:
*   priority: Priority of the interrupt. 0 - 7, 0 being the highest.
*
* Return:
*   None
*
*******************************************************************************/
void PulsehitimeISR_SetPriority(uint8 priority)
{
    *PulsehitimeISR_INTC_PRIOR = priority << 5;
}


/*******************************************************************************
* Function Name: PulsehitimeISR_GetPriority
********************************************************************************
*
* Summary:
*   Gets the Priority of the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   Priority of the interrupt. 0 - 7, 0 being the highest.
*
*******************************************************************************/
uint8 PulsehitimeISR_GetPriority(void)
{
    uint8 priority;


    priority = *PulsehitimeISR_INTC_PRIOR >> 5;

    return priority;
}


/*******************************************************************************
* Function Name: PulsehitimeISR_Enable
********************************************************************************
*
* Summary:
*   Enables the interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void PulsehitimeISR_Enable(void)
{
    /* Enable the general interrupt. */
    *PulsehitimeISR_INTC_SET_EN = PulsehitimeISR__INTC_MASK;
}


/*******************************************************************************
* Function Name: PulsehitimeISR_GetState
********************************************************************************
*
* Summary:
*   Gets the state (enabled, disabled) of the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   1 if enabled, 0 if disabled.
*
*******************************************************************************/
uint8 PulsehitimeISR_GetState(void)
{
    /* Get the state of the general interrupt. */
    return ((*PulsehitimeISR_INTC_SET_EN & (uint32)PulsehitimeISR__INTC_MASK) != 0u) ? 1u:0u;
}


/*******************************************************************************
* Function Name: PulsehitimeISR_Disable
********************************************************************************
*
* Summary:
*   Disables the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void PulsehitimeISR_Disable(void)
{
    /* Disable the general interrupt. */
    *PulsehitimeISR_INTC_CLR_EN = PulsehitimeISR__INTC_MASK;
}


/*******************************************************************************
* Function Name: PulsehitimeISR_SetPending
********************************************************************************
*
* Summary:
*   Causes the Interrupt to enter the pending state, a software method of
*   generating the interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void PulsehitimeISR_SetPending(void)
{
    *PulsehitimeISR_INTC_SET_PD = PulsehitimeISR__INTC_MASK;
}


/*******************************************************************************
* Function Name: PulsehitimeISR_ClearPending
********************************************************************************
*
* Summary:
*   Clears a pending interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void PulsehitimeISR_ClearPending(void)
{
    *PulsehitimeISR_INTC_CLR_PD = PulsehitimeISR__INTC_MASK;
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
