/*******************************************************************************
* File Name: ResolutionClk.h
* Version 2.20
*
*  Description:
*   Provides the function and constant definitions for the clock component.
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_CLOCK_ResolutionClk_H)
#define CY_CLOCK_ResolutionClk_H

#include <cytypes.h>
#include <cyfitter.h>


/***************************************
* Conditional Compilation Parameters
***************************************/

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component cy_clock_v2_20 requires cy_boot v3.0 or later
#endif /* (CY_PSOC5LP) */


/***************************************
*        Function Prototypes
***************************************/

void ResolutionClk_Start(void) ;
void ResolutionClk_Stop(void) ;

#if(CY_PSOC3 || CY_PSOC5LP)
void ResolutionClk_StopBlock(void) ;
#endif /* (CY_PSOC3 || CY_PSOC5LP) */

void ResolutionClk_StandbyPower(uint8 state) ;
void ResolutionClk_SetDividerRegister(uint16 clkDivider, uint8 restart) 
                                ;
uint16 ResolutionClk_GetDividerRegister(void) ;
void ResolutionClk_SetModeRegister(uint8 modeBitMask) ;
void ResolutionClk_ClearModeRegister(uint8 modeBitMask) ;
uint8 ResolutionClk_GetModeRegister(void) ;
void ResolutionClk_SetSourceRegister(uint8 clkSource) ;
uint8 ResolutionClk_GetSourceRegister(void) ;
#if defined(ResolutionClk__CFG3)
void ResolutionClk_SetPhaseRegister(uint8 clkPhase) ;
uint8 ResolutionClk_GetPhaseRegister(void) ;
#endif /* defined(ResolutionClk__CFG3) */

#define ResolutionClk_Enable()                       ResolutionClk_Start()
#define ResolutionClk_Disable()                      ResolutionClk_Stop()
#define ResolutionClk_SetDivider(clkDivider)         ResolutionClk_SetDividerRegister(clkDivider, 1u)
#define ResolutionClk_SetDividerValue(clkDivider)    ResolutionClk_SetDividerRegister((clkDivider) - 1u, 1u)
#define ResolutionClk_SetMode(clkMode)               ResolutionClk_SetModeRegister(clkMode)
#define ResolutionClk_SetSource(clkSource)           ResolutionClk_SetSourceRegister(clkSource)
#if defined(ResolutionClk__CFG3)
#define ResolutionClk_SetPhase(clkPhase)             ResolutionClk_SetPhaseRegister(clkPhase)
#define ResolutionClk_SetPhaseValue(clkPhase)        ResolutionClk_SetPhaseRegister((clkPhase) + 1u)
#endif /* defined(ResolutionClk__CFG3) */


/***************************************
*             Registers
***************************************/

/* Register to enable or disable the clock */
#define ResolutionClk_CLKEN              (* (reg8 *) ResolutionClk__PM_ACT_CFG)
#define ResolutionClk_CLKEN_PTR          ((reg8 *) ResolutionClk__PM_ACT_CFG)

/* Register to enable or disable the clock */
#define ResolutionClk_CLKSTBY            (* (reg8 *) ResolutionClk__PM_STBY_CFG)
#define ResolutionClk_CLKSTBY_PTR        ((reg8 *) ResolutionClk__PM_STBY_CFG)

/* Clock LSB divider configuration register. */
#define ResolutionClk_DIV_LSB            (* (reg8 *) ResolutionClk__CFG0)
#define ResolutionClk_DIV_LSB_PTR        ((reg8 *) ResolutionClk__CFG0)
#define ResolutionClk_DIV_PTR            ((reg16 *) ResolutionClk__CFG0)

/* Clock MSB divider configuration register. */
#define ResolutionClk_DIV_MSB            (* (reg8 *) ResolutionClk__CFG1)
#define ResolutionClk_DIV_MSB_PTR        ((reg8 *) ResolutionClk__CFG1)

/* Mode and source configuration register */
#define ResolutionClk_MOD_SRC            (* (reg8 *) ResolutionClk__CFG2)
#define ResolutionClk_MOD_SRC_PTR        ((reg8 *) ResolutionClk__CFG2)

#if defined(ResolutionClk__CFG3)
/* Analog clock phase configuration register */
#define ResolutionClk_PHASE              (* (reg8 *) ResolutionClk__CFG3)
#define ResolutionClk_PHASE_PTR          ((reg8 *) ResolutionClk__CFG3)
#endif /* defined(ResolutionClk__CFG3) */


/**************************************
*       Register Constants
**************************************/

/* Power manager register masks */
#define ResolutionClk_CLKEN_MASK         ResolutionClk__PM_ACT_MSK
#define ResolutionClk_CLKSTBY_MASK       ResolutionClk__PM_STBY_MSK

/* CFG2 field masks */
#define ResolutionClk_SRC_SEL_MSK        ResolutionClk__CFG2_SRC_SEL_MASK
#define ResolutionClk_MODE_MASK          (~(ResolutionClk_SRC_SEL_MSK))

#if defined(ResolutionClk__CFG3)
/* CFG3 phase mask */
#define ResolutionClk_PHASE_MASK         ResolutionClk__CFG3_PHASE_DLY_MASK
#endif /* defined(ResolutionClk__CFG3) */

#endif /* CY_CLOCK_ResolutionClk_H */


/* [] END OF FILE */
